; InputBox
; A window that prompts for a string.
; Inputs: hl -> InputBox structure
;
; InputBox Structure:
; .db "Title",0
; .db num_lines
; .db "Text line 1",0
; .db "Text line 2",0
; .db "Text line 3",0
; .dw wheretostore
;
; Comments:
;  This is just a messagebox and a stringinput at the same time. See the respective
;   documentation for explanations of the stuff there.
;

guiInputBox:
 res textwrite,(iy+sgrflags)
 set plotLoc,(iy+plotFlags)
 res fracDrawLFont,(iy+fontFlags)
 push hl
 ld hl,13*256+22
 ld de,47*256+73
 B_CALL _DrawRectBorderC
 ld hl,14*256+23
 ld de,19*256+72
 B_CALL _FillRect
 pop hl
 set textinverse,(iy+textflags)
 ld de,13*256+47
 ld (pencol),de
 call centertext
 res textinverse,(iy+textflags)
 ld de,20*256+24
 call multilinetextL
 ld de,39*256+24
 ld bc,12*256+0
 ld a,(hl)
 inc hl
 ld h,(hl)
 ld l,a
 jp guiStringInput


; InputBoxEX
; A window that propmts for a string with extra options.
; Inputs: hl -> InputBoxEX structure
; Outputs: 
;
; InputBoxEX Structure:
; .db flags
; .db height,width,titleheight
; .db num_titles
; .db "Title 1",0
; .db "Title 2",0
; .db num_lines
; .db "Line 1",0
; .db "Line 2",0
; .db "Line 3",0
; [.dw callback]
; .db inputflags
; .db maxchars
; .db col,row
; .dw wheretostore
;
; Comments:
;  This is just a simplified messagebox and a stringinput. See the respective documentation
;   for better explanations. Remember to use only IB (and SI) prefixed flags though.
;  Regardless of the buffer setting, the typed in text will only be displayed to the screen.
;  Standard values for inputflags, maxchars, col, and row are 0,12,24,39 respectively.
;

IB_Buffer			equ	0
IB_CenterTitle		equ	1
IB_CenterText		equ	2
IB_BigTitle			equ	3
IB_BigText			equ	4
IB_CustomText		equ	5

guiInputBoxEX:
 push hl
 push hl
 pop ix
 set plotLoc,(iy+plotFlags)
 res textwrite,(iy+sgrflags)
 bit IB_Buffer,(ix)
 jr z,guiInputBoxEXNoBuffer
 res plotLoc,(iy+plotFlags)
 set textwrite,(iy+sgrflags)
guiInputBoxEXNoBuffer:
 ld a,(ix+1)      ;height
 sra a
 neg
 add a,31
 ld h,a
 add a,(ix+1)
 ld d,a
 ld a,(ix+2)      ;width
 sra a
 neg
 add a,47
 ld l,a
 add a,(ix+2)
 ld e,a
 push hl
 push de
 push ix
 B_CALL _DrawRectBorderC
 pop ix
 pop de
 pop hl
 ld a,(ix+3)
 add a,h
 ld d,a
 B_CALL _FillRect
 pop hl           ;get pointer again
 ld de,4
 add hl,de
 set textinverse,(iy+textflags)
 res fracDrawLFont,(iy+fontFlags)
 bit IB_BigTitle,(ix)
 jr z,guiInputBoxEXTitleSmall
 set fracDrawLFont,(iy+fontFlags)
guiInputBoxEXTitleSmall:
 bit IB_CenterTitle,(ix)
 jr z,guiInputBoxEXTitleLeft
 ld a,(ix+1)
 sra a
 neg
 add a,31
 bit fracDrawLFont,(iy+fontFlags)
 jr z,guiInputBoxEXTitleNoShift
 inc a
guiInputBoxEXTitleNoShift:
 ld d,a
 ld e,47
 ld (pencol),de
 call multilinetextC
 jr guiInputBoxEXTitleDone
guiInputBoxEXTitleLeft:
 ld a,(ix+1)
 sra a
 neg
 add a,31
 bit fracDrawLFont,(iy+fontFlags)
 jr z,guiInputBoxEXTitleNoShift2
 inc a
guiInputBoxEXTitleNoShift2:
 ld d,a
 ld a,(ix+2)
 sra a
 neg
 add a,48
 ld e,a
 ld (pencol),de
 call multilinetextL
guiInputBoxEXTitleDone:
 res textinverse,(iy+textflags)
 res fracDrawLFont,(iy+fontFlags)
 bit IB_BigText,(ix)
 jr z,guiInputBoxEXTextSmall
 set fracDrawLFont,(iy+fontFlags)
guiInputBoxEXTextSmall:
 bit IB_CenterText,(ix)
 jr z,guiInputBoxEXTextLeft
 ld a,(ix+1)
 sra a
 neg
 add a,32
 bit fracDrawLFont,(iy+fontFlags)
 jr z,guiInputBoxEXTextNoShift
 inc a
guiInputBoxEXTextNoShift:
 add a,(ix+3)
 ld d,a
 ld e,47
 call multilinetextC
 jr guiInputBoxEXTextDone
guiInputBoxEXTextLeft:
 ld a,(ix+1)
 sra a
 neg
 add a,32
 bit fracDrawLFont,(iy+fontFlags)
 jr z,guiInputBoxEXTextNoShift2
 inc a
guiInputBoxEXTextNoShift2:
 add a,(ix+3)
 ld d,a
 ld a,(ix+2)
 sra a
 neg
 add a,49
 ld e,a
 call multilinetextL
guiInputBoxEXTextDone:
 bit IB_Buffer,(ix)
 jr z,guiInputBoxEXNoBuffer2
 B_CALL _grbufcpy
guiInputBoxEXNoBuffer2:
 bit IB_CustomText,(ix)
 jr z,guiStringInput
 ld a,(hl)
 inc hl
 push hl
 ld h,(hl)
 ld l,a
 ld de,guiInputBoxEXCallbackRet
 push de
 jp (hl)
guiInputBoxEXCallbackRet:
 pop hl
 inc hl
 jp guiStringInputST
