; Menu
; Title and list of choices.
; Inputs: hl -> Menu structure
; Outputs: a = Chosen option, first = 0, second = 1, etc
;
; Menu Structure:
; .db "Title",0
; .db num_choices
; .db "Choice 0",0
; .db "Choice 1",0
; .db "Choice 2",0
; .db "Choice 3",0
;
; Comments:
;  You may have no more than nine choices. There is no srolling.
;  The routine clears the screen before executing.
;  The buffer is unchanged by this routine.
;

guiMenu:
 set textinverse,(iy+textflags)
 set plotloc,(iy+plotflags)
 set texterasebelow,(iy+textflags)
 res textwrite,(iy+textflags)
 res fracDrawLFont,(iy+fontFlags)
 push hl
 B_CALL _clrlcdf
 ld hl,0
 ld de,6*256+95
 B_CALL _fillrect
 ld hl,0*256+47
 ld (pencol),hl
 pop hl
 call centertext
 ld e,0				; e = current choice
 ld c,(hl)			; c = maxchoices
guiMenuRedraw:
 ld d,0				; d = upward counter
 push hl
 push hl
 ld hl,1*256+0
 ld (pencol),hl
 pop hl
 ld b,(hl)			; b = downward counter
 inc hl
guiMenuDrawLoop:
 push de
 push hl
 ld hl,(pencol)
 ld a,7
 add a,h
 ld h,a
 ld l,0
 ld (pencol),hl
 ld a,d
 cp e
 jr nz,guiMenuNotInverse
 set textinverse,(iy+textflags)
guiMenuNotInverse:
 add a,31h
 push af
 ld a,20h
 B_CALL _vputmap
 pop af
 B_CALL _vputmap
 ld a,lcolon
 B_CALL _vputmap
 res textinverse,(iy+textflags)
 ld a,6
 B_CALL _vputmap
 pop hl
 pop de
 B_CALL _vputs
 inc d
 djnz guiMenuDrawLoop
 pop hl
guiMenuKeyLoop:
 ei
 halt
 push hl
 B_CALL _getcsc
 pop hl
 cp skEnter
 jr z,guiMenuSelect
 dec a
 jr z,guiMenuDown
 sub 3
 jr z,guiMenuUp
 push hl
 push de
 ld hl,guiStringInputNumTable-1
 ld e,a
 ld d,0
 add hl,de
 ld a,(hl)
 pop de
 pop hl
 sub 31h
 jr c,guiMenuKeyLoop
 cp c
 jr nc,guiMenuKeyLoop
 ret
guiMenuSelect:
 ld a,e
 ret
guiMenuDown:
 inc e
 ld a,e
 cp c
 jr nz,guiMenuRedraw
 ld e,0
 jr guiMenuRedraw
guiMenuUp:
 ld a,e
 dec e
 or a
 jr nz,guiMenuRedraw
 ld e,c
 dec e
 jr guiMenuRedraw


; MenuEX
; Title and list of choices, with options.
; Inputs: hl -> MenuEX structure
; Outputs: a = chosen option's value
;
; .db flags						; See below
; .db titleheight				; Height of the title bar
; .db num_titles				; Number of lines in the title
; .db "Title 1",0				; First line of the title
; .db "Title 2",0				; Second line of the title
; .db defaultchoice			; Choice that is highlighted by default
; .db num_choices				; Total number of choices
; .db Choice1Val				; Return value of the first choice
; .db "Choice 1",0			; The first choice text
; .db Choice2Val				; The return value of the second choice
; .db "Choice 2",0			; The second choice text
; .db Choice3Val				; ...
; .db "Choice 3",0			; ...
; [.dw textroutine]			; Optional callback text routine
;
; Flags:									SET (nz)									RESET (z)
;  Bit 0: ME_Buffer					Copied to screen and buffer		Just Displayed to screen
;  Bit 1: ME_CenterTitle			Title is centered						Title is left aligned
;  Bit 2: ME_BigTitle				Title is in large font				Title is in small font
;  Bit 3: ME_BigText					Text is in large font				Text is in small font
;  Bit 4: ME_CustomText				A callback routine exists			No callback
;  Bit 5: ME_ClearQuit				Clear returns a value of -1		Clear does nothing
;
; Comments:
;  There is no scrolling. Do not use more items than will fit on the screen.
;  The custom text routine is called after every time the choices are redrawn. The current
;   selection is in register "e". You do not need to preserve any registers or flags, but
;   text flags are not generally in a normal state when this call is made.
;

ME_Buffer			equ	0
ME_CenterTitle		equ	1
ME_BigTitle			equ	2
ME_BigText			equ	3
ME_CustomText		equ	4
ME_ClearQuit		equ	5

guiMenuEX:
 set textinverse,(iy+textflags)
 set plotloc,(iy+plotflags)
 set texterasebelow,(iy+textflags)
 res textwrite,(iy+textflags)
 res fracDrawLFont,(iy+fontFlags)
 push hl
 push hl
 pop ix
 bit ME_Buffer,(hl)
 jr z,guiMenuEXNoBufferWindow
 res plotLoc,(iy+plotFlags)
 B_CALL _clrgbuf
guiMenuEXNoBufferWindow:
 B_CALL _clrlcdf
 ld hl,0
 ld e,95
 ld d,(ix+1)
 B_CALL _fillrect
 pop hl
 inc hl
 inc hl
 ld d,0
 bit ME_BigTitle,(ix)
 jr z,guiMenuEXSmallTitle
 set fracDrawLFont,(iy+fontFlags)
 inc d
guiMenuEXSmallTitle:
 bit ME_Buffer,(ix)
 jr nz,guiMenuEXBufferTitle
 bit ME_CenterTitle,(ix)
 push af
 ld e,47
 call nz,multilinetextC
 pop af
 ld e,1
 call z,multilinetextL
 jr guiMenuEXNoBufferTitle
guiMenuEXBufferTitle:
 bit ME_CenterTitle,(ix)
 push af
 ld e,47
 call nz,multilinetextC2
 pop af
 ld e,1
 call z,multilinetextL2
guiMenuEXNoBufferTitle:
 ld e,(hl)			; e = current choice
 inc hl
 ld c,(hl)			; c = maxchoices
guiMenuEXRedraw:
 ld d,0				; d = upward counter
 push hl
 res textinverse,(iy+textflags)
 res fracDrawLFont,(iy+fontFlags)
 bit ME_BigText,(ix)
 jr z,guiMenuEXSmallText
 set fracDrawLFont,(iy+fontFlags)
guiMenuEXSmallText:
 push hl
 ld a,(ix+1)
 sub 5
 ld h,a
 ld l,0
 ld (pencol),hl
 pop hl
 ld b,(hl)			; b = downward counter
 inc hl
guiMenuEXDrawLoop:
 push de
 push hl
 ld hl,(pencol)
 ld a,7
 bit ME_BigText,(ix)
 jr z,guiMenuEXSmallText2
 ld a,8
guiMenuEXSmallText2:
 add a,h
 ld h,a
 ld l,0
 ld (pencol),hl
 ld a,d
 cp e
 jr nz,guiMenuEXNotInverse
 set textinverse,(iy+textflags)
guiMenuEXNotInverse:
 add a,31h
 bit ME_BigText,(ix)
 jr nz,guiMenuExNoInitialSpace
 push af
 ld a,20h
 call vputmapc
 pop af
guiMenuExNoInitialSpace:
 call vputmapc
 ld a,lcolon
 call vputmapc
 res textinverse,(iy+textflags)
 ld a,6
 bit ME_BigText,(ix)
 jr z,guiMenuEXFourSpaces
 ld a,20h
guiMenuEXFourSpaces:
 call vputmapc
 pop hl
 inc hl
 pop de
 bit ME_Buffer,(ix)
 push af
 call nz,vputs2
 pop af
 jr nz,guiMenuEXTextDone
 B_CALL _vputs
guiMenuEXTextDone:
 inc d
 djnz guiMenuEXDrawLoop
 bit ME_CustomText,(ix)
 jr z,guiMenuEXNoCallback
 push ix
 push de
 push bc
 push hl
 ld hl,guiMenuEXCallbackRet
 ex (sp),hl
 ld a,(hl)
 inc hl
 ld h,(hl)
 ld l,a
 jp (hl)
guiMenuEXCallbackRet:
 pop bc
 pop de
 pop ix
guiMenuEXNoCallback:
 pop hl
 res fracDrawLFont,(iy+fontFlags)
guiMenuEXKeyLoop:
 ei
 halt
 push hl
 B_CALL _getcsc
 pop hl
 cp skEnter
 jr z,guiMenuEXSelect
 cp skClear
 jr z,guiMenuEXClear
 dec a
 jr z,guiMenuEXDown
 sub 3
 jr z,guiMenuEXUp
 push hl
 push de
 ld hl,guiStringInputNumTable-1
 ld e,a
 ld d,0
 add hl,de
 ld a,(hl)
 pop de
 pop hl
 sub 31h
 jr c,guiMenuEXKeyLoop
 cp c
 jr nc,guiMenuEXKeyLoop
 ld e,a
guiMenuEXSelect:
 ld b,e
 ld a,b
 or a
 jr z,guiMenuEXGetValueSkip
guiMenuEXGetValueLoop:
 inc hl
 call nextstr
 djnz guiMenuEXGetValueLoop
guiMenuEXGetValueSkip:
 ld a,(hl)
 ret
guiMenuEXDown:
 inc e
 ld a,e
 cp c
 jp nz,guiMenuEXRedraw
 ld e,0
 jp guiMenuEXRedraw
guiMenuEXUp:
 ld a,e
 dec e
 or a
 jp nz,guiMenuEXRedraw
 ld e,c
 dec e
 jp guiMenuEXRedraw
guiMenuEXClear:
 bit ME_ClearQuit,(ix)
 jr z,guiMenuEXKeyLoop
 ld a,0ffh
 ret
vputmapc:
 bit ME_Buffer,(ix)
 push af
 call nz,vputmap2
 pop af
 ret nz
 push ix
 B_CALL _vputmap
 pop ix
 ret
